@@ -44,12 +44,13 @@ int wordcount(char *);
 int parse(char *, int, char *, char *, int, int);
 int oer_doquery(char *, int level, const char *, ...);
 int issamenickandhost(char *, char *, char *, char *);
+unsigned int longestword(char *);
+unsigned int isgoodquote(char *);
 void striplf(char *);
 void stripchars(char *, char *);
 void stripcntrl(char *);
 void stripansi(char *);
 void stripmirc(char *);
-void safequote(char *);
 void oer_debug(int, const char *, ...);
 void secondstostring(time_t, char *, int);
 void sortstring(char *);
@@ -160,9 +161,10 @@ int oer_doquery(char *function, int level, const char *fmt, ...)
 		return 0;
 	}
 	gettimeofday(&tv2, NULL);
-	snprintf(stringbuffer, TXT_BUFFER, "%ld secs and %ld usecs", tv2.tv_sec - tv1.tv_sec, ABS(tv2.tv_usec - tv1.tv_usec));
 	if(tv2.tv_sec == tv1.tv_sec) {
 		snprintf(stringbuffer, TXT_BUFFER, "%ld usecs", tv2.tv_usec - tv1.tv_usec);
+	} else {
+		snprintf(stringbuffer, TXT_BUFFER, "%ld secs and %ld usecs", tv2.tv_sec - tv1.tv_sec, ABS(tv2.tv_usec - tv1.tv_usec));
 	}
 #ifdef DEBUG
 	oer_debug(level, "oer_doquery->mysql_query took %s\n", stringbuffer);
@@ -654,3 +656,58 @@ void sortstring(char *string)
                 }
         }
 }
+
+unsigned int longestword(char *quote)
+{
+        int len;
+        int pos;
+        int max;
+        int wlen;
+
+        len = strlen(quote);
+        pos = 0;
+        max = 0;
+        while(pos < len) {
+                while(pos < len && isspace((int)quote[pos])) {
+                        pos++;
+                }
+                wlen = 0;
+                while(pos < len && !isspace((int)quote[pos])) {
+                        wlen++;
+                        pos++;
+                }
+                if(wlen > max) {
+                        max = wlen;
+                }
+        }
+        return max;
+}
+
+unsigned int isgoodquote(char *quote)
+{
+        /* we want a string longer than OER_QUOTE_MIN_LENGTH */
+        if(strlen(quote) < OER_QUOTE_MIN_LENGTH) {
+                return 0;
+        }
+        /* we want a string shorter than OER_QUOTE_MAX_LENGTH */
+        if(strlen(quote) > OER_QUOTE_MAX_LENGTH) {
+                return 0;
+        }
+        /* we want the string to contain at least 2 words */
+        if(wordcount(quote) < 3) {
+                return 0;
+        }
+        /* no word of the string should be longer than OER_QUOTE_MAX_WORD_LENGTH */
+        if(longestword(quote) > OER_QUOTE_MAX_WORD_LENGTH) {
+                return 0;
+        }
+	/* no strings with (c) in them */
+	if(strstr(quote, "(c)")) {
+		return 0;
+	}
+	/* no strings with http:// in them */
+	if(strstr(quote, "http://")) {
+		return 0;
+	}
+        return 1;
+}
