@@ -995,6 +995,7 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 	int ppos;
 	int is_command;
 	struct channel *this;
+	char np[NICKLEN + 1];
 #ifdef DEBUG
         oer_debug(OER_DEBUG_INFO, "parsemsg(\"%s\", \"%s\", \"%s\", \"%s\")\n", nick, userhost, target, message);
 #endif
@@ -1064,6 +1065,9 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 	if(this->i_am_op && checkforbadword(this, nick, userhost, message)) {
 		return;
 	}
+	if(this->i_am_op && checkforaction(this, nick, userhost, ctcp)) {
+                return;
+        }
 	/* only add this consequetive line iff the user
 	   isn't being kicked already (lag between kick and last message) */
 	if(!gettobek(this, nick)) {
@@ -1074,24 +1078,17 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 		return;
 	}
 	/* check for command */
+        ppos = 0;
         is_command = 0;
-	ppos = 0;
-	if(!strncasecmp(message, mystate->nick, strlen(mystate->nick))) {
-                is_command = 1;
-                ppos = strlen(mystate->nick);
-                if(isspace((int)message[ppos])) {
-                        while(isspace((int)message[ppos])) {
-                                ppos++;
-                        }
+	if((ppos = parse(message, ppos, " ", np, NICKLEN, 0)) >= 0) {
+                /* it is possible that parse() will fail if message
+                   has just one word and it is longer than NICKLEN */
+                if(!strcasecmp(np, mystate->nick)) {
+                        is_command = 1;
                 }
-        }
-        if(!strncasecmp(message, mystate->prefix, strlen(mystate->prefix))) {
-                is_command = 1;
-                ppos = strlen(mystate->prefix);
-                if(isspace((int)message[ppos])) {
-                        while(isspace((int)message[ppos])) {
-                                ppos++;
-                        }
+                if(!strncasecmp(np, mystate->prefix, strlen(mystate->prefix))) {
+                        is_command = 1;
+                        ppos = strlen(mystate->prefix);
                 }
         }
         if(is_command) {
